Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type SlotCluster ¶
type SlotCluster struct {
// contains filtered or unexported fields
}
SlotCluster is a map to return service host
func NewSlotCluster ¶
func NewSlotCluster(conn *zk.Conn) SlotCluster
NewSlotCluster is a help function, we will try to read from the zk, if it is not existed, we will init it and dispatch all to default service
Click to show internal directories.
Click to hide internal directories.